pub struct EncodedBlurredRoundedRectangle {}Expand description
An encoded blurred, rounded rectangle.
Fields
exponent: f32An component for computing the blur effect.
recip_exponent: f32An component for computing the blur effect.
scale: f32An component for computing the blur effect.
std_dev_inv: f32An component for computing the blur effect.
min_edge: f32An component for computing the blur effect.
w: f32An component for computing the blur effect.
h: f32An component for computing the blur effect.
width: f32An component for computing the blur effect.
height: f32An component for computing the blur effect.
r1: f32An component for computing the blur effect.
invert: boolWhether to paint the inverse (1 - alpha) of the blur coverage.
When true, the paint is fully opaque outside the blurred rectangle and fades to
transparent inside it. This is useful for implementing inset box shadows.
color: PremulColorThe base color for the blurred rectangle.
transform: AffineA transform that needs to be applied to the position of the first processed pixel.
x_advance: Vec2How much to advance into the x/y direction for one step in the x direction.
y_advance: Vec2How much to advance into the x/y direction for one step in the y direction.