EncodedExternalTexture

Struct EncodedExternalTexture 

pub struct EncodedExternalTexture {
    pub texture_id: TextureId,
    pub source_region: RectU16,
    pub sampler: ImageSampler,
    pub may_have_transparency: bool,
    pub transform: Affine,
    pub tint: Option<Tint>,
}
An encoded external texture.

The texture must be bound by the user at render-time in order for us to be able to sample from it; it is not interned into the renderer.

Fields

texture_id: TextureId

External texture handle.

source_region: RectU16

Source region of the texture in texel coordinates.

sampler: ImageSampler

Sampler parameters.

may_have_transparency: bool

Whether the sampled content may contain non-opaque pixels.

transform: Affine

Inverse destination transform, mapping scene coordinates to local source-rect space.

tint: Option<Tint>

Optional tint applied to the sampled color.