pub struct EncodedImage {
pub source: ImageSource,
pub sampler: ImageSampler,
pub may_have_transparency: bool,
pub transform: Affine,
pub x_advance: Vec2,
pub y_advance: Vec2,
pub tint: Option<Tint>,
}Expand description
An encoded image.
Fields
source: ImageSourceThe underlying pixmap of the image.
sampler: ImageSamplerSampler
may_have_transparency: boolWhether the image has opacities.
transform: AffineA transform to apply to the image.
x_advance: Vec2The advance in image coordinates for one step in the x direction.
y_advance: Vec2The advance in image coordinates for one step in the y direction.
tint: Option<Tint>Optional tint applied to the image.