pub struct EncodedExternalTexture {
pub texture_id: TextureId,
pub source_region: RectU16,
pub sampler: ImageSampler,
pub may_have_transparency: bool,
pub transform: Affine,
pub tint: Option<Tint>,
}Expand description
An encoded external texture.
The texture must be bound by the user at render-time in order for us to be able to sample from it; it is not interned into the renderer.
Fields
texture_id: TextureIdExternal texture handle.
source_region: RectU16Source region of the texture in texel coordinates.
sampler: ImageSamplerSampler parameters.
may_have_transparency: boolWhether the sampled content may contain non-opaque pixels.
transform: AffineInverse destination transform, mapping scene coordinates to local source-rect space.
tint: Option<Tint>Optional tint applied to the sampled color.